package org.tinygroup.permission.fileresolver;

import org.tinygroup.fileresolver.impl.AbstractFileProcessor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.permission.PermissionConfigManager;
import org.tinygroup.permission.config.PermissionConfigs;
import org.tinygroup.springutil.SpringUtil;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.xstream.XStreamFactory;

import com.thoughtworks.xstream.XStream;
/**
 * 
 * 功能说明: 权限配置文件处理器
 * <p> 系统版本: v1.0<br>
 * 开发人员: renhui <br>
 * 开发时间: 2013-8-14 <br>
 * 功能描述: 写明作用，调用方式，使用场景，以及特殊情况<br>
 */
public class PermissionConfigFileProcessor extends AbstractFileProcessor {
	
	private static final String PERMISSION_CONFIG_EXT_FILENAME=".permissionconfig.xml";

	public boolean isMatch(FileObject fileObject) {
		return fileObject.getFileName().endsWith(PERMISSION_CONFIG_EXT_FILENAME);
	}

	public void process() {
		PermissionConfigManager manager = SpringUtil
				.getBean(PermissionConfigManager.PERMISSION_MANAGER_BEAN_NAME);
		XStream stream = XStreamFactory
				.getXStream(PermissionConfigManager.XSTEAM_PACKAGE_NAME);
		for (FileObject fileObject : fileObjects) {
			logger.logMessage(LogLevel.DEBUG, "正在加载权限配置文件[{0}]",
					fileObject.getAbsolutePath());
			PermissionConfigs configs = (PermissionConfigs) stream
					.fromXML(fileObject.getInputStream());
			manager.addPermissionConfigs(configs);
			logger.logMessage(LogLevel.DEBUG, "加载权限配置文件[{0}]结束",
					fileObject.getAbsolutePath());
		}
	}

}
